@@ -1,7 +1,6 @@
-from contextlib import nullcontext
 from enum import Enum
-from random import choices
-from typing import Any, Callable, List, Tuple, Type
+from typing import Callable, List, Tuple, Type
+from .utils import get_type_hints, is_annotated
 import inflection
 from rekuest.api.schema import (
     PortInput,
@@ -9,11 +8,8 @@ from rekuest.api.schema import (
     DefinitionInput,
     NodeKindInput,
     PortKindInput,
-    ReturnWidgetInput,
-    WidgetInput,
     AnnotationInput,
 )
-from typing import Optional
 import inspect
 from docstring_parser import parse
 from rekuest.definition.errors import DefinitionError
@@ -34,15 +30,18 @@ def convert_child_to_childport(
     Args:
         cls (Type): The type (class or annotation) of the elemtn
         registry (StructureRegistry): The structure registry to use
-        nullable (bool, optional): Is this type optional (recursive parameter). Defaults to False.
+        nullable (bool, optional): Is this type optional (recursive parameter).
+            Defaults to False.
         is_return (bool, optional): Is this a return type?. Defaults to False.
-        annotations (List[AnnotationInput], optional): The annotations for this element. Defaults to None.
+        annotations (List[AnnotationInput], optional): The annotations for this element.
+            Defaults to None.
 
     Returns:
-        Tuple[ChildPortInput, WidgetInput, Callable]: The child port, the widget and the converter for the default
+        Tuple[ChildPortInput, WidgetInput, Callable]: The child port, the widget and the
+         converter for the default
     """
 
-    if hasattr(cls, "__name__") and cls.__name__ == "Annotated":
+    if is_annotated(cls):
         real_type = cls.__args__[0]
 
         annotations = [
@@ -58,7 +57,6 @@ def convert_child_to_childport(
         )
 
     if cls.__module__ == "typing":
-
         if hasattr(cls, "_name"):
             # We are dealing with a Typing Var?
             if cls._name == "List":
@@ -73,9 +71,11 @@ def convert_child_to_childport(
                         nullable=nullable,
                         annotations=annotations,
                     ),
-                    lambda default: [nested_converter(ndefault) for ndefault in default]
-                    if default
-                    else None,
+                    lambda default: (
+                        [nested_converter(ndefault) for ndefault in default]
+                        if default
+                        else None
+                    ),
                 )
 
             if cls._name == "Dict":
@@ -89,12 +89,14 @@ def convert_child_to_childport(
                         nullable=nullable,
                         annotations=annotations,
                     ),
-                    lambda default: {
-                        key: item in nested_converter(item)
-                        for key, item in default.items()
-                    }
-                    if default
-                    else None,
+                    lambda default: (
+                        {
+                            key: item in nested_converter(item)
+                            for key, item in default.items()
+                        }
+                        if default
+                        else None
+                    ),
                 )
 
         if hasattr(cls, "__args__"):
@@ -112,7 +114,7 @@ def convert_child_to_childport(
                 nullable=nullable,
                 annotations=annotations,
             )  # catch bool is subclass of int
-            return t, None, None, str
+            return t, str
 
         if not issubclass(cls, Enum) and issubclass(cls, int):
             return (
@@ -121,8 +123,6 @@ def convert_child_to_childport(
                     nullable=nullable,
                     annotations=annotations,
                 ),
-                None,
-                None,
                 int,
             )
         if not issubclass(cls, Enum) and issubclass(cls, str):
@@ -132,16 +132,13 @@ def convert_child_to_childport(
                     nullable=nullable,
                     annotations=annotations,
                 ),
-                None,
-                None,
                 str,
             )
 
     identifier = registry.get_identifier_for_structure(cls)
     default_converter = registry.get_default_converter_for_structure(cls)
-    assign_widget =  registry.get_widget_input(cls)
-    print(assign_widget)
-    return_widget  = registry.get_returnwidget_input(cls)
+    assign_widget = registry.get_widget_input(cls)
+    return_widget = registry.get_returnwidget_input(cls)
 
     return (
         ChildPortInput(
@@ -170,7 +167,7 @@ def convert_object_to_port(
     """
     Convert a class to an Port
     """
-    if hasattr(cls, "__name__") and cls.__name__ == "Annotated":
+    if is_annotated(cls):
         real_type = cls.__args__[0]
 
         annotations = [
@@ -189,11 +186,10 @@ def convert_object_to_port(
         )
 
     if cls.__module__ == "typing":
-
         if hasattr(cls, "_name"):
             # We are dealing with a Typing Var?
             if cls._name == "List":
-                child,  converter = convert_child_to_childport(
+                child, converter = convert_child_to_childport(
                     cls.__args__[0], registry, nullable=False
                 )
                 return PortInput(
@@ -209,7 +205,7 @@ def convert_object_to_port(
                 )
 
             if cls._name == "Dict":
-                child,  converter = convert_child_to_childport(
+                child, converter = convert_child_to_childport(
                     cls.__args__[1], registry, nullable=False
                 )
                 return PortInput(
@@ -218,9 +214,11 @@ def convert_object_to_port(
                     returnWidget=return_widget,
                     key=key,
                     child=child,
-                    default={key: converter(item) for key, item in default.items()}
-                    if default
-                    else None,
+                    default=(
+                        {key: converter(item) for key, item in default.items()}
+                        if default
+                        else None
+                    ),
                     nullable=nullable,
                     annotations=annotations,
                     description=description,
@@ -359,7 +357,6 @@ def convert_return_to_returnport(
         )
 
     if cls.__module__ == "typing":
-
         if hasattr(cls, "_name"):
             # We are dealing with a Typing Var?
             if cls._name == "List":
@@ -462,6 +459,7 @@ def prepare_definition(
     omitfirst=None,
     omitlast=None,
     omitkeys=[],
+    allow_annotations=True,
 ) -> DefinitionInput:
     """Define
 
@@ -470,7 +468,8 @@ def prepare_definition(
     return its definition(input).
 
     Attention this definition is not yet registered in the
-    arkitekt registry. This is done by the create_template function ( which will validate the definition with your local arkitekt instance
+    arkitekt registry. This is done by the create_template function ( which will
+    validate he definition with your local arkitekt instance
     and raise an error if the definition is not compatible with your arkitekt version)
 
 
@@ -495,10 +494,12 @@ def prepare_definition(
     # Docstring Parser to help with descriptions
     docstring = parse(function.__doc__)
     if docstring.long_description is None:
-        assert (
-            allow_empty_doc is not False
-        ), f"We don't allow empty documentation for function {function.__name__}. Please Provide"
+        assert allow_empty_doc is not False, (
+            f"We don't allow empty documentation for function {function.__name__}."
+            " Please Provide"
+        )
 
+    type_hints = get_type_hints(function, include_extras=allow_annotations)
     function_ins_annotation = sig.parameters
 
     doc_param_map = {param.arg_name: param.description for param in docstring.params}
@@ -511,7 +512,6 @@ def prepare_definition(
     }
 
     for index, (key, value) in enumerate(function_ins_annotation.items()):
-
         # We can skip arguments if the builder is going to provide additional arguments
         if omitfirst is not None and index < omitfirst:
             continue
@@ -522,7 +522,14 @@ def prepare_definition(
 
         widget = widgets.get(key, None)
         return_widget = return_widgets.get(key, None)
-        cls = value.annotation
+        default =  value.default if value.default != inspect.Parameter.empty else None
+        cls = type_hints.get(key, type(default) if default is not None else None)
+
+        if cls is None:
+            raise DefinitionError(
+                f"Could not find type hint for {key} in {function.__name__}. Please provide a type hint (or default) for this argument."
+            )
+
 
         try:
             args.append(
@@ -532,21 +539,19 @@ def prepare_definition(
                     structure_registry,
                     widget=widget,
                     return_widget=return_widget,
-                    default=value.default
-                    if value.default != inspect.Parameter.empty
-                    else None,
+                    default=default, 
                     description=doc_param_map.get(key, None),
                 )
             )
         except Exception as e:
             raise DefinitionError(
-                f"Could not convert Argument of function {function.__name__} to ArgPort: {value}"
+                f"Could not convert Argument of function {function.__name__} to"
+                f" ArgPort: {value}"
             ) from e
 
     function_outs_annotation = sig.return_annotation
 
     if hasattr(function_outs_annotation, "_name"):
-
         if function_outs_annotation._name == "Tuple":
             try:
                 for index, cls in enumerate(function_outs_annotation.__args__):
@@ -564,16 +569,17 @@ def prepare_definition(
                     )
             except Exception as e:
                 raise DefinitionError(
-                    f"Could not convert Return of function {function.__name__} to ArgPort: {cls}"
+                    f"Could not convert Return of function {function.__name__} to"
+                    f" ArgPort: {cls}"
                 ) from e
         else:
             try:
-                return_widget = return_widgets.get(f"return0", None)
-                widget = widgets.get(f"return0", None)
+                return_widget = return_widgets.get("return0", None)
+                widget = widgets.get("return0", None)
                 returns.append(
                     convert_object_to_port(
                         function_outs_annotation,
-                        f"return0",
+                        "return0",
                         structure_registry,
                         return_widget=return_widget,
                         widget=widget,
@@ -581,7 +587,8 @@ def prepare_definition(
                 )  # Other types will be converted to normal lists and shit
             except Exception as e:
                 raise DefinitionError(
-                    f"Could not convert Return of function {function.__name__} to ArgPort: {function_outs_annotation}"
+                    f"Could not convert Return of function {function.__name__} to"
+                    f" ArgPort: {function_outs_annotation}"
                 ) from e
     else:
         # We are dealing with a non tuple return
@@ -589,8 +596,8 @@ def prepare_definition(
             pass
 
         elif function_outs_annotation.__name__ != "_empty":  # Is it not empty
-            return_widget = return_widgets.get(f"return0", None)
-            widget = widgets.get(f"return0", None)
+            return_widget = return_widgets.get("return0", None)
+            widget = widgets.get("return0", None)
             returns.append(
                 convert_object_to_port(
                     function_outs_annotation,
